/// <reference types="react" />
import gsap from 'gsap';
interface AnimatedSidebar {
    /**
     * Open the sidebar at first render
     * Default: false
     */
    initiallyOpen?: boolean;
    /**
     * Apply width to the sidebar
     * Default: 200
     */
    sidebarWidth?: number | string;
    /**
     * Choose opening side
     * Default: false (right side)
     */
    leftSide?: boolean;
    /**
     * Apply zIndex to the sidebar
     * Default: 1
     */
    sidebarZIndex?: number;
    /**
     * Choose mode of the sidebar
     * Normal mode (not full width) the sidebar will push the content
     * Full width mode the sidebar will overlay the content (it uses the first relative parent)
     */
    fullWidth?: boolean;
    animatedFullWidthBody?: boolean;
}
/**
 * Hook to animate the SidebarContainer
 * Spread the returned props on the SidebarContainer
 * @param param0
 */
export declare const useSidebar: ({ initiallyOpen, sidebarWidth, fullWidth, leftSide, animatedFullWidthBody, }: AnimatedSidebar) => {
    toggleSidebar: (callback?: gsap.Callback) => Promise<void>;
    open: boolean;
    inTransition: boolean;
    state: {
        ref: import("react").RefObject<HTMLDivElement>;
        width: string | number;
        leftSide: boolean;
        fullWidth: boolean;
        open: boolean;
        inTransition: boolean;
    };
    bodyRef: import("react").RefObject<HTMLDivElement>;
};
export {};
